@@ -4,12 +4,10 @@ from collections import UserString
 
 from snakeoil.compatibility import cmp
 from snakeoil.demandload import demand_compile_regexp
-from snakeoil.klass import inject_richcmp_methods_from_cmp
-
-from pkgcore.ebuild import atom
-from pkgcore.ebuild.errors import InvalidCPV
-from pkgcore.package import base
 
+from ..package import base
+from . import atom
+from .errors import InvalidCPV
 
 demand_compile_regexp(
     'suffix_regexp', '^(alpha|beta|rc|pre|p)(\\d*)$')
@@ -46,7 +44,7 @@ def isvalid_rev(s):
     return s and s[0] == 'r' and s[1:].isdigit()
 
 
-class _Revision(UserString):
+class Revision(UserString):
     """Internal revision class storing revisions as strings and comparing as integers."""
 
     # parent __hash__() isn't inherited when __eq__() is defined in the child class
@@ -67,7 +65,7 @@ class _Revision(UserString):
             return self.data
 
     def __eq__(self, other):
-        if isinstance(other, _Revision):
+        if isinstance(other, Revision):
             return self._revint == other._revint
         elif isinstance(other, int):
             return self._revint == other
@@ -76,7 +74,7 @@ class _Revision(UserString):
         return self.data == other
 
     def __lt__(self, other):
-        if isinstance(other, _Revision):
+        if isinstance(other, Revision):
             return self._revint < other._revint
         elif isinstance(other, int):
             return self._revint < other
@@ -85,7 +83,7 @@ class _Revision(UserString):
         return self.data < other
 
     def __le__(self, other):
-        if isinstance(other, _Revision):
+        if isinstance(other, Revision):
             return self._revint <= other._revint
         elif isinstance(other, int):
             return self._revint <= other
@@ -94,7 +92,7 @@ class _Revision(UserString):
         return self.data <= other
 
     def __gt__(self, other):
-        if isinstance(other, _Revision):
+        if isinstance(other, Revision):
             return self._revint > other._revint
         elif isinstance(other, int):
             return self._revint > other
@@ -103,7 +101,7 @@ class _Revision(UserString):
         return self.data > other
 
     def __ge__(self, other):
-        if isinstance(other, _Revision):
+        if isinstance(other, Revision):
             return self._revint >= other._revint
         elif isinstance(other, int):
             return self._revint >= other
@@ -245,7 +243,6 @@ class CPV(base.base):
     """
 
     __slots__ = ("cpvstr", "key", "category", "package", "version", "revision", "fullver")
-    inject_richcmp_methods_from_cmp(locals())
 
     def __init__(self, *args, versioned=None):
         """
@@ -297,7 +294,7 @@ class CPV(base.base):
                     # needs at least ('pkg', 'ver', 'rev')
                     raise InvalidCPV(
                         cpvstr, 'missing package name, version, and/or revision')
-                rev = _Revision(pkg_chunks.pop(-1)[1:])
+                rev = Revision(pkg_chunks.pop(-1)[1:])
                 if rev == 0:
                     # reset stored cpvstr to drop -r0+
                     sf(self, 'cpvstr', f"{category}/{'-'.join(pkg_chunks)}")
@@ -306,7 +303,7 @@ class CPV(base.base):
                     sf(self, 'cpvstr', f"{category}/{'-'.join(pkg_chunks)}-r{int(rev)}")
                 sf(self, 'revision', rev)
             else:
-                sf(self, 'revision', _Revision(''))
+                sf(self, 'revision', Revision(''))
 
             if not isvalid_version_re.match(pkg_chunks[-1]):
                 raise InvalidCPV(cpvstr, f"invalid version '{pkg_chunks[-1]}'")
@@ -339,26 +336,70 @@ class CPV(base.base):
     def __str__(self):
         return getattr(self, 'cpvstr', 'None')
 
-    def __cmp__(self, other):
+    def __eq__(self, other):
         try:
             if self.cpvstr == other.cpvstr:
-                return 0
-
-            if (self.category and other.category and self.category != other.category):
-                return cmp(self.category, other.category)
-
-            if self.package and other.package and self.package != other.package:
-                return cmp(self.package, other.package)
-
-            # note I chucked out valueerror, none checks on versions
-            # passed in. I suck, I know.
-            # ~harring
-            # fails in doing comparison of unversioned atoms against
-            # versioned atoms
-            return ver_cmp(
-                self.version, self.revision, other.version, other.revision)
+                return True
+            if self.category == other.category and self.package == other.package:
+                return ver_cmp(self.version, self.revision, other.version, other.revision) == 0
         except AttributeError:
-            return 1
+            pass
+        return False
+
+    def __ne__(self, other):
+        return not self.__eq__(other)
+
+    def __lt__(self, other):
+        try:
+            if self.category == other.category:
+                if self.package == other.package:
+                    return ver_cmp(self.version, self.revision, other.version, other.revision) < 0
+                return self.package < other.package
+            return self.category < other.category
+        except AttributeError:
+            raise TypeError(
+                "'<' not supported between instances of "
+                f"{self.__class__.__name__!r} and {other.__class__.__name__!r}"
+            )
+
+    def __le__(self, other):
+        try:
+            if self.category == other.category:
+                if self.package == other.package:
+                    return ver_cmp(self.version, self.revision, other.version, other.revision) <= 0
+                return self.package < other.package
+            return self.category < other.category
+        except AttributeError:
+            raise TypeError(
+                "'<=' not supported between instances of "
+                f"{self.__class__.__name__!r} and {other.__class__.__name__!r}"
+            )
+
+    def __gt__(self, other):
+        try:
+            if self.category == other.category:
+                if self.package == other.package:
+                    return ver_cmp(self.version, self.revision, other.version, other.revision) > 0
+                return self.package > other.package
+            return self.category > other.category
+        except AttributeError:
+            raise TypeError(
+                "'>' not supported between instances of "
+                f"{self.__class__.__name__!r} and {other.__class__.__name__!r}"
+            )
+
+    def __ge__(self, other):
+        try:
+            if self.category == other.category:
+                if self.package == other.package:
+                    return ver_cmp(self.version, self.revision, other.version, other.revision) >= 0
+                return self.package > other.package
+            return self.category > other.category
+        except AttributeError:
+            raise TypeError(
+                "'>=' not supported between instances of "
+                f"{self.__class__.__name__!r} and {other.__class__.__name__!r}"
+            )
 
     @property
     def versioned_atom(self):
