@@ -1,18 +1,17 @@
-from collections import defaultdict
-from functools import partial
 import os
 import re
 import subprocess
 import sys
+from collections import defaultdict
+from functools import partial
 
-from snakeoil import mappings, weakrefs, klass
+from snakeoil import klass, mappings, weakrefs
 from snakeoil.demandload import demand_compile_regexp
 from snakeoil.osutils import pjoin
 from snakeoil.process.spawn import bash_version
 
-from pkgcore.ebuild import atom, const
-from pkgcore.log import logger
-
+from ..log import logger
+from . import atom, const
 
 demand_compile_regexp(
     '_valid_EAPI_regex', r"^[A-Za-z0-9_][A-Za-z0-9+_.-]*$"
@@ -220,6 +219,27 @@ class EAPI(metaclass=klass.immutable_instance):
             return True
         return False
 
+    @klass.jit_attr
+    def bash_funcs_global(self):
+        """Internally implemented global EAPI specific functions to skip when exporting."""
+        # TODO: This is currently duplicated across EAPI objs, but
+        # instead could be cached to a class attr.
+        funcs = pjoin(const.EBD_PATH, '.generated', 'funcs', 'global')
+        if not os.path.exists(funcs):
+            # we're probably running in a cacheless git repo, so generate a cached version
+            try:
+                os.makedirs(os.path.dirname(funcs), exist_ok=True)
+                with open(funcs, 'w') as f:
+                    subprocess.run(
+                        [pjoin(const.EBD_PATH, 'generate_global_func_list')],
+                        cwd=const.EBD_PATH, stdout=f)
+            except (IOError, subprocess.CalledProcessError) as e:
+                raise Exception(
+                    f"failed to generate list of global EAPI '{self}' specific functions: {str(e)}")
+
+        with open(funcs, 'r') as f:
+            return frozenset(line.strip() for line in f)
+
     @klass.jit_attr
     def bash_funcs(self):
         """Internally implemented EAPI specific functions to skip when exporting."""
@@ -239,6 +259,25 @@ class EAPI(metaclass=klass.immutable_instance):
         with open(funcs, 'r') as f:
             return frozenset(line.strip() for line in f)
 
+    @klass.jit_attr
+    def bash_cmds_internal(self):
+        """EAPI specific commands for this EAPI."""
+        cmds = pjoin(const.EBD_PATH, '.generated', 'cmds', self._magic, 'internal')
+        if not os.path.exists(cmds):
+            # we're probably running in a cacheless git repo, so generate a cached version
+            try:
+                os.makedirs(os.path.dirname(cmds), exist_ok=True)
+                with open(cmds, 'w') as f:
+                    subprocess.run(
+                        [pjoin(const.EBD_PATH, 'generate_eapi_cmd_list'), '-i', self._magic],
+                        cwd=const.EBD_PATH, stdout=f)
+            except (IOError, subprocess.CalledProcessError) as e:
+                raise Exception(
+                    f'failed to generate list of EAPI {self} internal commands: {str(e)}')
+
+        with open(cmds, 'r') as f:
+            return frozenset(line.strip() for line in f)
+
     @klass.jit_attr
     def bash_cmds_deprecated(self):
         """EAPI specific commands deprecated for this EAPI."""
@@ -439,7 +478,7 @@ common_dep_keys = (
 )
 
 common_metadata_keys = (
-    "RESTRICT", "PROPERTIES", "DEFINED_PHASES", "INHERITED", "EAPI",
+    "RESTRICT", "PROPERTIES", "DEFINED_PHASES", "INHERIT", "INHERITED", "EAPI",
 )
 
 common_eclass_keys = ("S", "RESTRICT", "PROPERTIES", "ECONF_SOURCE")
