@@ -4,21 +4,21 @@ built ebuild packages (vdb packages and binpkgs are derivatives of this)
 
 __all__ = ("package", "package_factory")
 
-from functools import partial
 import itertools
+from functools import partial
 
 from snakeoil.currying import post_curry
 from snakeoil.data_source import local_source
 from snakeoil.mappings import IndeterminantDict
 from snakeoil.obj import DelayedInstantiation
 
-from pkgcore import fetch
-from pkgcore.ebuild import ebd, ebuild_src, conditionals, triggers
-from pkgcore.ebuild.eapi import get_eapi
-from pkgcore.fs.livefs import scan
-from pkgcore.merge import engine
-from pkgcore.package import metadata
-from pkgcore.package.base import DynamicGetattrSetter
+from .. import fetch
+from ..fs.livefs import scan
+from ..merge import engine
+from ..package import metadata
+from ..package.base import DynamicGetattrSetter
+from . import conditionals, ebd, ebuild_src, triggers
+from .eapi import get_eapi
 
 
 def _passthrough(inst, attr):
@@ -110,6 +110,10 @@ class package(ebuild_src.base):
     def inherited(self):
         return tuple(self.data.get("INHERITED", "").split())
 
+    @DynamicGetattrSetter.register
+    def inherit(self):
+        return tuple(self.data.get("INHERIT", "").split())
+
     @DynamicGetattrSetter.register
     def source_repository(self):
         repo = self.data.get('source_repository')
