@@ -4,12 +4,12 @@ Ebuild repository, specific to gentoo ebuild trees.
 
 __all__ = ("UnconfiguredTree", "ConfiguredTree", "ProvidesRepo", "tree")
 
-from functools import partial, wraps
-from itertools import chain, filterfalse
 import locale
-from operator import attrgetter
 import os
 import stat
+from functools import partial, wraps
+from itertools import chain, filterfalse
+from operator import attrgetter
 from random import shuffle
 from sys import intern
 
@@ -20,26 +20,26 @@ from snakeoil.data_source import local_source
 from snakeoil.fileutils import readlines
 from snakeoil.mappings import ImmutableDict
 from snakeoil.obj import make_kls
-from snakeoil.osutils import listdir_files, listdir_dirs, pjoin
+from snakeoil.osutils import listdir_dirs, listdir_files, pjoin
 from snakeoil.sequences import iflatten_instance, stable_unique
 from snakeoil.strings import pluralism as _pl
 from snakeoil.weakrefs import WeakValCache
 
-from pkgcore import fetch
-from pkgcore.config.hint import ConfigHint, configurable
-from pkgcore.ebuild import (
-    cpv, digest, ebd, repo_objs, atom, restricts, processor,
-    ebuild_src, eclass_cache as eclass_cache_mod, errors as ebuild_errors,
-)
-from pkgcore.ebuild.eapi import get_eapi
-from pkgcore.fs.livefs import sorted_scan
-from pkgcore.log import logger
-from pkgcore.operations import repo as _repo_ops
-from pkgcore.package import errors as pkg_errors
-from pkgcore.repository import prototype, errors, configured, util
-from pkgcore.repository.virtual import RestrictionRepo
-from pkgcore.restrictions import packages
-from pkgcore.util.packages import groupby_pkg
+from .. import fetch
+from ..config.hint import ConfigHint, configurable
+from ..fs.livefs import sorted_scan
+from ..log import logger
+from ..operations import repo as _repo_ops
+from ..package import errors as pkg_errors
+from ..repository import configured, errors, prototype, util
+from ..repository.virtual import RestrictionRepo
+from ..restrictions import packages
+from ..util.packages import groupby_pkg
+from . import atom, cpv, digest, ebd, ebuild_src
+from . import eclass_cache as eclass_cache_mod
+from . import errors as ebuild_errors
+from . import processor, repo_objs, restricts
+from .eapi import get_eapi
 
 
 class repo_operations(_repo_ops.operations):
@@ -323,7 +323,8 @@ class UnconfiguredTree(prototype.tree):
         typename='repo')
 
     def __init__(self, location, eclass_cache=None, masters=(), cache=(),
-                 default_mirrors=None, allow_missing_manifests=False, repo_config=None):
+                 default_mirrors=None, allow_missing_manifests=False, package_cache=True,
+                 repo_config=None):
         """
         :param location: on disk location of the tree
         :param cache: sequence of :obj:`pkgcore.cache.template.database` instances
@@ -334,9 +335,12 @@ class UnconfiguredTree(prototype.tree):
             if None, generates the eclass_cache itself
         :param default_mirrors: Either None, or sequence of mirrors to try
             fetching from first, then falling back to other uri
+        :param package_cache: boolean controlling package instance caching
+        :param repo_config: :obj:`pkgcore.repo_objs.RepoConfig` instance for the related repo
         """
         super().__init__()
         self.base = self.location = location
+        self.package_cache = package_cache
         if repo_config is None:
             repo_config = repo_objs.RepoConfig(location)
         self.config = repo_config
@@ -529,7 +533,7 @@ class UnconfiguredTree(prototype.tree):
         while True:
             try:
                 pkg = next(pkgs)
-            except pkg_errors.PackageError as e:
+            except pkg_errors.PackageError:
                 # ignore pkgs with invalid CPVs
                 continue
             except StopIteration:
