@@ -1,30 +1,30 @@
 """system cleaning utility"""
 
 import argparse
-from collections import defaultdict
 import errno
-from functools import partial
 import glob
-from itertools import chain
 import os
 import re
 import shutil
 import sys
 import time
+from collections import defaultdict
+from functools import partial
+from itertools import chain
 
 from snakeoil.mappings import DictMixin
 from snakeoil.osutils import listdir_dirs, listdir_files, pjoin
 from snakeoil.sequences import iflatten_instance, split_negations
 from snakeoil.strings import pluralism
 
-from pkgcore.ebuild import atom as atom_mod
-from pkgcore.ebuild.domain import domain as domain_cls
-from pkgcore.repository import multiplex
-from pkgcore.repository.util import SimpleTree, get_virtual_repos
-from pkgcore.restrictions import boolean, packages
-from pkgcore.util import parserestrict
-from pkgcore.util.commandline import ArgumentParser, StoreRepoObject, convert_to_restrict
-
+from ..ebuild import atom as atom_mod
+from ..ebuild.domain import domain as domain_cls
+from ..repository import multiplex
+from ..repository.util import SimpleTree, get_virtual_repos
+from ..restrictions import boolean, packages
+from ..util import parserestrict
+from ..util.commandline import (ArgumentParser, StoreRepoObject,
+                                convert_to_restrict)
 
 argparser = ArgumentParser(description=__doc__, script=(__file__, __name__))
 subparsers = argparser.add_subparsers(description='cleaning applets')
