@@ -14,21 +14,23 @@ running them on source repos makes no sense.
 """
 
 import errno
-from functools import partial
 import os
+from functools import partial
 
 from snakeoil.cli import arghparse
 from snakeoil.formatters import decorate_forced_wrapping
 from snakeoil.osutils import pjoin, sizeof_fmt
 from snakeoil.sequences import iter_stable_unique
 
-from pkgcore import const
-from pkgcore.ebuild import conditionals, atom
-from pkgcore.fs import fs as fs_module
-from pkgcore.repository import multiplex
-from pkgcore.repository.util import get_raw_repos, get_virtual_repos
-from pkgcore.restrictions import packages, values, boolean
-from pkgcore.util import commandline, parserestrict, packages as pkgutils
+from .. import const
+from ..ebuild import atom, conditionals
+from ..fs import fs as fs_module
+from ..repository import multiplex
+from ..repository.util import get_raw_repos, get_virtual_repos
+from ..restrictions import boolean, packages, values
+from ..util import commandline
+from ..util import packages as pkgutils
+from ..util import parserestrict
 
 
 class DataSourceRestriction(values.base):
